@@ -87,12 +87,13 @@ class Graph(BaseGraph):
         self.nodes['tooltip'] = self.svg.node(
             self.nodes['tooltip_overlay'],
             id="tooltip",
-            transform='translate(0 0)')
+            transform='translate(0 0)',
+            style="opacity: 0")
 
         a = self.svg.node(self.nodes['tooltip'], 'a')
         self.svg.node(a, 'rect',
                       id="tooltip-box",
-                      rx=5, ry=5,
+                      rx=5, ry=5, width=0, height=0
         )
         text = self.svg.node(a, 'text', class_='text')
         self.svg.node(text, 'tspan', class_='label')
