@@ -114,7 +114,7 @@ class Line(Graph):
             self._box.ymax = self._max
 
         y_pos = compute_scale(
-            self._box.ymin, self._box.ymax, self.logarithmic
+            self._box.ymin, self._box.ymax, self.logarithmic, self.order_min
         ) if not self.y_labels else map(float, self.y_labels)
 
         self._x_labels = self.x_labels and zip(self.x_labels, x_pos)
