@@ -128,7 +128,7 @@ class Radar(Line):
         self._box.xmax = self._box.ymax = self._rmax = self._max
 
         y_pos = compute_scale(
-            0, self._box.ymax, self.logarithmic, max_scale=8
+            0, self._box.ymax, self.logarithmic, self.order_min, max_scale=8
         ) if not self.y_labels else map(int, self.y_labels)
         self._x_labels = self.x_labels and zip(self.x_labels, x_pos)
         self._y_labels = zip(map(self._format, y_pos), y_pos)
