@@ -16,8 +16,9 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
-from pygal import Line
+from pygal import Line, Dot, Pie, Radar
 from pygal.test.utils import texts
+from pygal.test import pytest_generate_tests, make_data
 
 
 def test_logarithmic():
